import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// Colors for the sections in Pie Chart
const sectionColors = [
  		'red', 'green', 'blue', 'pink', 'yellow', 'orange', 'grey', 'black', 'purple', 'indigo'
		  ];

// Data set URI
const csvUrl = 'https://gist.githubusercontent.com/rohithbollareddy/175c0f2717d9513e7de7b6a94f555c6d/raw/4f7197ecb2a4f4a3a142b1d0384992f2d1cbda49/deathRates-top20%2520states';

// Function to fetch data from the URI
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

// Format axes text
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// Render Pie Chart on the canvas
const render = (data, total) => {
  const pieData = pie().value(d=>d.Deaths)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  // Object for generating Arcs of the sections
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(350);

  
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(205)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.Deaths));
  
  // Render text on each section
  sections
    .enter()
    .append('text')

    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);
  
  // Render legend for the data
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*40})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Deaths));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.States);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.Deaths)));
}

// Main function
const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.Deaths = +d.Deaths;
    total += d.Deaths
  });
	render(data,total);
};
run();